<?php

namespace Drupal\easy_email\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for Easy Email global settings.
 */
class EasyEmailSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'easy_email_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'easy_email.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('easy_email.settings');

    $form['#tree'] = TRUE;

    $form['purge'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Automatic Email Deletion'),
    ];

    $form['purge']['cron'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Delete emails automatically on cron run'),
      '#default_value' => $config->get('purge_on_cron'),
      '#description' => $this->t('Emails will be automatically deleted based on the settings for each template.
        This checkbox determines whether that happens on cron run or whether you will run the included Drush command separately.'),
    ];

    $form['purge']['cron_limit'] = [
      '#type' => 'number',
      '#title' => $this->t('Maximum number of emails to delete per cron run'),
      '#default_value' => $config->get('purge_cron_limit'),
      '#states' => [
        'required' => [
          ':input[name="purge[cron]"]' => ['checked' => TRUE],
        ],
      ]
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('easy_email.settings');
    $config->set('purge_on_cron', $form_state->getValue(['purge', 'cron']));
    $config->set('purge_cron_limit', $form_state->getValue(['purge', 'cron_limit']));

    $config->save();
    parent::submitForm($form, $form_state);
  }

}
